@@ -112,7 +112,6 @@ fn parse_args() -> Args {
                 } else {
                     vec!["clear-cache", "list-templates"]
                 })
-                .number_of_values(1)
                 .conflicts_with_all(if cfg!(windows) {
                     &["list-templates", "install-file-association", "uninstall-file-association"]
                 } else {
@@ -122,7 +121,7 @@ fn parse_args() -> Args {
             .arg(Arg::new("script-args")
                 .index(2)
                 .about("Arguments for the script to execute.")
-                .multiple(true)
+                .multiple_values(true)
                 .min_values(0)
             )
             .arg(Arg::new("expr")
@@ -165,7 +164,7 @@ fn parse_args() -> Args {
                 .long("dep")
                 .short('d')
                 .takes_value(true)
-                .multiple(true)
+                .multiple_occurrences(true)
                 .number_of_values(1)
             )
             .arg(Arg::new("dep_extern")
@@ -173,7 +172,7 @@ fn parse_args() -> Args {
                 .long("dep-extern")
                 .short('D')
                 .takes_value(true)
-                .multiple(true)
+                .multiple_occurrences(true)
                 .requires("expr_or_loop")
             )
             .arg(Arg::new("extern")
@@ -181,7 +180,7 @@ fn parse_args() -> Args {
                 .long("extern")
                 .short('x')
                 .takes_value(true)
-                .multiple(true)
+                .multiple_occurrences(true)
                 .requires("expr_or_loop")
             )
             .arg(Arg::new("features")
@@ -194,7 +193,7 @@ fn parse_args() -> Args {
                 .long("unstable-feature")
                 .short('u')
                 .takes_value(true)
-                .multiple(true)
+                .multiple_occurrences(true)
                 .requires("expr_or_loop")
             )
 
